@@ -1,16 +1,19 @@
+## no critic: Subroutines::ProhibitSubroutinePrototypes
 package Getopt::Long::Patch::DumpAndExit;
 
-our $DATE = '2016-10-27'; # DATE
-our $VERSION = '0.10'; # VERSION
-
 use 5.010001;
 use strict;
 no warnings;
 
 use Data::Dmp;
-use Module::Patch 0.19 qw();
+use Module::Patch ();
 use base qw(Module::Patch);
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-08-10'; # DATE
+our $DIST = 'Getopt-Long-Dump'; # DIST
+our $VERSION = '0.110'; # VERSION
+
 our %config;
 
 sub _dump {
@@ -23,7 +26,6 @@ sub _dump {
 sub _GetOptions(@) {
     if (ref($_[0]) eq 'HASH') {
         my $h = shift;
-        _dump({ map {$_ => sub{}} @_ });
     } else {
         _dump({@_});
     }
@@ -34,11 +36,10 @@ sub _GetOptionsFromArray(@) {
     # discard array
     shift;
     if (ref($_[0]) eq 'HASH') {
+        # discard hash storage
         my $h = shift;
-        _dump({ map {$_ => sub{}} @_ });
-    } else {
-        _dump({@_});
     }
+    _dump([@_]);
     $config{-exit_method} eq 'exit' ? exit(0) : die;
 }
 
@@ -47,10 +48,8 @@ sub _GetOptionsFromString(@) {
     shift;
     if (ref($_[0]) eq 'HASH') {
         my $h = shift;
-        _dump({ map {$_ => sub{}} @_ });
-    } else {
-        _dump({@_});
     }
+    _dump([@_]);
     $config{-exit_method} eq 'exit' ? exit(0) : die;
 }
 
@@ -102,7 +101,7 @@ Getopt::Long::Patch::DumpAndExit - Patch Getopt::Long to dump option spec and ex
 
 =head1 VERSION
 
-This document describes version 0.10 of Getopt::Long::Patch::DumpAndExit (from Perl distribution Getopt-Long-Dump), released on 2016-10-27.
+This document describes version 0.110 of Getopt::Long::Patch::DumpAndExit (from Perl distribution Getopt-Long-Dump), released on 2022-08-10.
 
 =head1 DESCRIPTION
 
@@ -119,6 +118,35 @@ Please visit the project's homepage at L<https://metacpan.org/release/Getopt-Lon
 
 Source repository is at L<https://github.com/perlancar/perl-Getopt-Long-Dump>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2016, 2015, 2014 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Getopt-Long-Dump>
@@ -127,15 +155,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2016 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
